---
title: '[공지] PortOne(포트원)을 사칭한 문자 메세지 주의 안내'
category: 공지사항
tags:
  - 공지사항
searchTags:
  - 코인
  - 로또
  - 사칭
datetime: 2024-04-30T07:22:27.400Z
---

안녕하세요. 포트원 고객지원팀입니다.

최근 포트원을 사칭하여 로또/코인 보상 관련으로 유선 및 문자메세지가 발송된 사례가 있어 안내해 드립니다.

메세지에 포함된  <Highlight text="사이트 링크로 접속하시거나, 유선통화 시 개인정보 및 금융 정보 유출 피해가 발생될 수 있으니 각별한 주의" /> 부탁드립니다.

포트원에서는 위와 같은 내용으로 문자메세지를 발송하지 않습니다.

감사합니다.
